@@ -60,4 +60,4 @@ class ExtendedJsonEncoder(json.JSONEncoder):
         elif isinstance(o, datetime.date):
             return o.isoformat()
 
-        return super(StandardProperlyTypeEncoder, self).default(o)
+        return super(ExtendedJsonEncoder, self).default(o)
